#! /usr/bin/env python2
# -*- coding: utf-8 -*-
 
from mininet.topo import Topo
from mininet.net import Mininet
from mininet.node import RemoteController
from mininet.cli import CLI
from mininet.log import setLogLevel, info

"""
Custom topology example to demonstrate VLANs

      | s1 |-------| s2 |-----| s3 |
       /  \                    /  \  
      /    \                  /    \
   [h1]    [h2]            [h3]    [h4]
 
"""

# Declare variables
ryu_ip = '127.0.0.1'
ryu_port = 6653
  
class MyTopo( Topo ):
    """Create a custom network class"""
  
    def __init__(self):
        """ Constructor method """

        # Initialise topology
        Topo.__init__(self)

        # Add switches
        s1,s2,s3 = [ self.addSwitch(s) for s in ('s1', 's2', 's3') ]

        # Add hosts
        h1, h2, h3 = [ self.addHost(h) for h in ('h1', 'h2', 'h3') ]

        # Add links
        for sa, sb in [ (s1, s2), (s2, s3) ]:
            self.addLink( sa, sb )

        for h, s in [ (h1, s1), (h2, s2), (h3, s3) ]:
            self.addLink( h, s )

# main() function
def main():
    """Test custom network"""

    topo = MyTopo()
    net = Mininet(topo=topo, controller=None)
    net.addController('c0', controller=RemoteController,ip=ryu_ip, port=ryu_port)

    info('*** Starting network ***\n')
    net.start()

    info('*** Running CLI ***\n' )
    CLI(net)

    info('*** Stopping network ***' )
    net.stop()

# Call run_net() function
if __name__ == '__main__':
    setLogLevel('info')
    main()

exit(0)

