#! /usr/bin/env python2
# -*- coding: utf-8 -*-
 
from mininet.topo import Topo
from mininet.net import Mininet
from mininet.node import RemoteController
from mininet.cli import CLI
from mininet.log import setLogLevel, info

"""
Custom topology example to demonstrate VLANs

      | s1 |--------| s2 |---------| s3 |
       /  \          /  \           /  \        
      /    \        /    \         /    \       
   [h1]    [h2]  [h3]    [h4]   [h5]    [h6]
 
"""

# Declare variables
ryu_ip = '127.0.0.1'
ryu_port = 6653
  
class MyTopo( Topo ):
    """Create a custom network class"""
  
    def __init__(self):
        """ Constructor method """

        # Initialise topology
        Topo.__init__(self)

        # Add switches
        s1,s2,s3 = [ self.addSwitch(s) for s in ('s1', 's2', 's3') ]

        # Add hosts 
        h1 = self.addHost('h1', ip='192.168.1.1/24', mac='00:00:00:00:00:01')
        h2 = self.addHost('h2', ip='192.168.1.2/24', mac='00:00:00:00:00:02')
        h3 = self.addHost('h3', ip='192.168.1.3/24', mac='00:00:00:00:00:03')
        h4 = self.addHost('h4', ip='192.168.1.4/24', mac='00:00:00:00:00:04')
        h5 = self.addHost('h5', ip='192.168.1.5/24', mac='00:00:00:00:00:05')
        h6 = self.addHost('h6', ip='192.168.1.6/24', mac='00:00:00:00:00:06')

        # Add links
        for sa, sb in [(s1, s2), (s2, s3)]:
            self.addLink( sa, sb )

        for h, s in [(h1, s1), (h2, s1), (h3, s2), (h4, s2), (h5, s3), (h6, s3)]:
            self.addLink( h, s )

# main() function
def main():
    """Test custom network"""

    topo = MyTopo()
    net = Mininet(topo=topo, controller=None)
    net.addController('c0', controller=RemoteController,ip=ryu_ip, port=ryu_port)

    info('*** Starting network ***\n')
    net.start()

    info('*** Running CLI ***\n' )
    CLI(net)

    info('*** Stopping network ***' )
    net.stop()

# Call run_net() function
if __name__ == '__main__':
    setLogLevel('info')
    main()

exit(0)

